Uses of Class org.openqa.selenium.server.browserlaunchers.locators.FirefoxLocator (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

## Uses of Class
org.openqa.selenium.server.browserlaunchers.locators.FirefoxLocator

Packages that use FirefoxLocator
org.openqa.selenium.server.browserlaunchers.locators |

Uses of FirefoxLocator in org.openqa.selenium.server.browserlaunchers.locators

Subclasses of FirefoxLocator in org.openqa.selenium.server.browserlaunchers.locators
`class` | `Firefox2Locator` Discovers a valid Firefox 2.x installation on local system.
`class` | `Firefox3Locator` Discovers a valid Firefox 2.x or 3.x installation on local system.

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

Copyright © 2009. All Rights Reserved.